$(function() {
  // Prep list items
  $('ul li').each(function() {
    $list_item = $(this);

    if ($list_item.hasClass('expanded')) {
      $list_item.prepend('<img src="expanded.png" class="collapser">');
    }
    else if ($list_item.hasClass('collapsed')) {
      $list_item.prepend('<img src="collapsed.png" class="collapser">');
    }
    else {
      // Not expanded or collapsed. First check if it has kids
      if ($list_item.find('ul').length) {
        // Has children, so make it collapsed
        $list_item.addClass('collapsed');
        $list_item.prepend('<img src="collapsed.png" class="collapser">');
      }
      else {
        // No children, make it a leaf
        $list_item.addClass('leaf');
        $list_item.prepend('<img src="bullet.png" class="bullet">');
      }
    }

    // Handle clicks on the arrow
    $list_item.find('img.collapser').click(function() {
      var parent_item = $(this).parent('li');

      // Expanded: collapse it
      if (parent_item.hasClass('expanded')) {
        parent_item.removeClass('expanded').addClass('collapsed');
        $(this).attr('src', 'collapsed.png');
      }
      // Collapsed: expand it
      else {
        parent_item.removeClass('collapsed').addClass('expanded');
        $(this).attr('src', 'expanded.png');
      }
    });
  });

  // Handle clicks on the link
  $('ul li a').click(function() {
    DevGuideTOC.markActiveTOCItem(this);
  });

  // Check if a particular page has been requested
  var requested_path = DevGuideTOC.getURLParameter('topic');
  if (requested_path) {
    // Trim the leading slash
    if (requested_path[0] == '/') {
      requested_path = requested_path.substr(1);
    }

    // Find the list item to activate it
    var active_path_item = $('a[href="' + requested_path + '"]').first();
    if (active_path_item.length) {
      // Run the click handler to set the classes
      active_path_item.trigger('click');
    }
    else {
      // No list item found, meaning it's a hidden page that doesn't appear in
      // the TOC. Make sure no other item is marked active.
      $('li').removeClass('activeItem');
    }
    // Load the page into the content frame
    parent.frames.mainFrame.location = requested_path;
  }
});


var DevGuideTOC = {
  /**
   * Get a named GET parameter from the URL
   * With thanks to Stack Overflow: http://stackoverflow.com/a/1404100/2185
   */
  getURLParameter: function(name) {
    return decodeURIComponent(
      (RegExp(name + '=' + '(.+?)(&|$)').exec(parent.location.search)||[,''])[1]
    );
  },


  /**
   * Update the breadcrumb in the main frame
   */
  getBreadcrumbs: function(path) {
    // Only take the part of the path beginning at org.tizen.
    var relative_path = path.substr(path.indexOf('org.tizen.'));
    var path_root = path.substr(0, path.indexOf('org.tizen.'));

    var breadcrumbs = [];

    // Find the link to the given path
    var active_path_item = $('a[href="' + relative_path + '"]').first();
    if (!active_path_item.length) {
      // No link with that path found. If it's referring to an item in a
      // sub-TOC, the href on the link might be something like:
      // org.tizen.thing/../org.tizen.subtoc.thing/whatever
      // So check for links that *end* with the requested path
      active_path_item = $('a[href$="../' + relative_path + '"]').first();
    }
    if (active_path_item.length) {
      // Activate the TOC item
      this.markActiveTOCItem(active_path_item);

      // Find the li right above this link
      var parent_list_item = active_path_item.parent('li');
      // Iterate up over the parent li elements
      parent_list_item.parents('li').each(function() {
        var link = $(this).find('a').first();
        if (link) {
          var href = path_root + link.attr('href');
          var link_text = link.text();
          var newLink = '<a href="' + href + '">' + link_text + '</a>';
          breadcrumbs.push(newLink);
        }
      });
    }
    // Return breadcrumbs in the order they should be displayed
    return breadcrumbs.reverse();
  },


  /**
   * Activate the TOC link in the TOC frame
   */
  markActiveTOCItem: function(link) {
    var parent_list_item = $(link).parent('li');

    // Make sure no other item is marked active, and make this one active
    $('li').removeClass('activeItem');
    parent_list_item.addClass('activeItem');

    // Expand the parent items above this one
    var parent_list_item = $(link).parent('li');
    parent_list_item.parents('li').each(function() {
      $(this).addClass('expanded').removeClass('collapsed');
      $(this).find('img.collapser').first().attr('src', 'expanded.png');
    });
  }
};
